tisdb.config module — tisdb 0.0.1.dev0 documentation

# tisdb.config module

class `tisdb.config.` `TsdbConfig`(host: str = 'localhost', port: int = 3306, user: str = 'root', password: str = 'root', db: str = 'icuser', charset: str = 'utf8', autocommit: int = 0, cursorclass=<class 'pymysql.cursors.DictCursor'>)

  Bases: `sortedcontainers.sorteddict.SortedDict`

  Tsdb client config

  Args:

    host (str): connection host port (int): port user (str): auth user password (str): auth password db (str): tsdb namespace charset (str): conn charset autocommit (int): auto commit or not. Defaults to 0 means no

  `copy`() → tisdb.config.TsdbConfig

    Return a shallow copy of the sorted dict.

    Runtime complexity: O(n)

    Returns

      new sorted dict